@@ -1,12 +1,28 @@
-package Git::Background::Future;
+# vim: ts=4 sts=4 sw=4 et: syntax=perl
+#
+# Copyright (c) 2021-2022 Sven Kirmess
+#
+# Permission to use, copy, modify, and distribute this software for any
+# purpose with or without fee is hereby granted, provided that the above
+# copyright notice and this permission notice appear in all copies.
+#
+# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+package Git::Background::Future;
 
-use Future 0.40;
+our $VERSION = '0.006';
+
+use Future 0.49;
 
 use parent 'Future';
 
@@ -16,17 +32,18 @@ sub new {
     my ( $class, $run ) = @_;
 
     my $self = $class->SUPER::new;
-    $self->{_run} = $run;
+    $self->set_udata( '_run', $run );
     return $self;
 }
 
 sub await {
     my ($self) = @_;
 
-    return $self if $self->{ready};
+    my $run = $self->udata('_run');
 
-    return $self->fail( q{internal error: cannot find '_run'}, 'internal' ) if !defined $self->{_run};
-    my $run = delete $self->{_run};
+    return $self if !defined $run;
+
+    $self->set_udata( '_run', undef );
 
     my $e;
     my $ok = 1;
@@ -152,7 +169,8 @@ sub stdout {
 sub _await_if_git_is_done {
     my ($self) = @_;
 
-    if ( defined $self->{_run} && !$self->{_run}{_proc}->alive ) {
+    my $run = $self->udata('_run');
+    if ( defined $run && !$run->{_proc}->alive ) {
         $self->await;
     }
 
@@ -173,7 +191,7 @@ Git::Background::Future - use L<Future> with L<Git::Background>
 
 =head1 VERSION
 
-Version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -293,14 +311,4 @@ L<https://github.com/skirmess/Git-Background>
 
 Sven Kirmess <sven.kirmess@kzone.ch>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2021-2022 by Sven Kirmess.
-
-This is free software, licensed under:
-
-  The (two-clause) FreeBSD License
-
 =cut
-
-# vim: ts=4 sts=4 sw=4 et: syntax=perl
